cmd

package
v0.0.0-...-0bee801 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 1, 2024 License: AGPL-3.0 Imports: 14 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var Version = "0.1.0" // Default value for development builds

Version is the application version, set via ldflags during build.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func FetchFileNameByID

func FetchFileNameByID(id int) (string, error)

fetchFileNameByID checks if the file exists in the database and returns its name

func ParseFileID

func ParseFileID(fileIDStr string) (int, error)

parseFileID converts a string file ID to an integer and validates it

func ValidateGroupID

func ValidateGroupID(gid int)

validateGroupID checks if the provided group ID exists in the database.

Types

This section is empty.

Jump to