Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ( Config config Session *discordgo.Session // Reuse a single session )
Functions ¶
func DownloadPart ¶
Downloads the parts in same order as uploaded and joins each part on the fly, since each file is added to the file before and then closed, no big memory usage is observed
`Tested with 775mb file, hashes match` 'TODO: Add a way to check for sudden stops in download or stich if possible i.e. program crash in middle of function'
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.