Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Version = "0.1.0" // Default value for development builds
Version is the application version, set via ldflags during build.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func FetchFileNameByID ¶
fetchFileNameByID checks if the file exists in the database and returns its name
func ParseFileID ¶
parseFileID converts a string file ID to an integer and validates it
func ValidateGroupID ¶
func ValidateGroupID(gid int)
validateGroupID checks if the provided group ID exists in the database.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.