Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func DeleteFileParts ¶
The function deletes all the file parts of a file then finally deletes the file itself
It deletes the file first then it's registration in the parts table.
'TODO: Add a way to check for sudden stops in delete i.e. program crash in middle of function'
func DownloadAndReassembleFile ¶
Assembles the binary files in one big file
func FilePartsCalc ¶
FilePartsCalc calculates the number of parts required to split the file.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.